function exportIcons() {
	var doc;
	try { doc = app.activeDocument; } catch(e) { return reportError("No document active"); }
	if(!doc) return reportError("No document active");
	var docs = app.documents;
	var layers = doc.layers;
	var favicon48Layer, favicon32Layer, favicon16Layer, androidLayer, windowsLayer, iOSLayer;
    
    try { favicon32Layer = layers.getByName("export_favicon32"); } catch(e) { return reportError("Not a valid document (no export_favicon32 layer found)"); } // Favicon 32
    try { favicon16Layer = layers.getByName("export_favicon16"); } catch(e) { return reportError("Not a valid document (no export_favicon16 layer found)"); } // Favicon 16
    try { androidLayer = layers.getByName("export_android"); } catch(e) { return reportError("Not a valid document (no export_android layer found)"); } // Android
    try { windowsLayer = layers.getByName("export_windows"); } catch(e) { return reportError("Not a valid document (no export_windows layer found)"); } // Windows 10
    try { iOSLayer = layers.getByName("export_ios"); } catch(e) { return reportError("Not a valid document (no export_ios layer found)"); } // iOS
	
	var saveFolder = Folder.selectDialog("Select a folder to export to");
	
	if(!saveFolder) return;
	
	exportLayer(docs, favicon32Layer, "32px", "32px", saveFolder, "favicon-32.png"); // Favicon 32
	exportLayer(docs, favicon16Layer, "16px", "16px", saveFolder, "favicon-16.png"); // Favicon 16
	exportLayer(docs, androidLayer, "192px", "192px", saveFolder, "android-chrome-192.png"); // Android
	exportLayer(docs, windowsLayer, "270px", "270px", saveFolder, "ms-tile-270.png"); // Windows 10
	exportLayer(docs, iOSLayer, "180px", "180px", saveFolder, "apple-touch-icon-180.png"); // iOS
	
	// Optimize the images if we can
	var optimBin = File("/Applications/ImageOptim.app/Contents/MacOS/ImageOptim");
	
	if(optimBin && optimBin.exists) {
		app.system('/Applications/ImageOptim.app/Contents/MacOS/ImageOptim '+File.encode(saveFolder.fsName)+'/*.png');
	} else {
		alert("ImageOptim is not present, images were not optimized");
	}
	
	alert("Done!");
}

function exportLayer(docs, layer, width, height, folder, name) {
	layer.copy();
	var newDoc = docs.add(width, height, 72, "export layer", NewDocumentMode.RGB, DocumentFill.TRANSPARENT);
	newDoc.paste();
	
	var sfwOptions = new ExportOptionsSaveForWeb();
	sfwOptions.format = SaveDocumentType.PNG;
	sfwOptions.PNG8 = false;
	
	newDoc.exportDocument(File(folder.fsName+"/"+name), ExportType.SAVEFORWEB, sfwOptions);
	newDoc.close(SaveOptions.DONOTSAVECHANGES);
}

function reportError(message) {
	alert(message);
}

try {
	exportIcons();
} catch(e) {
	reportError("Unknown error occured");
}